# Section81SummaryResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**section_81_reference_number** | **str** |  | 
**date_created** | **datetime** |  | 
**location_description** | **str** |  | 
**section_81_severity** | [**Section81SeverityResponse**](Section81SeverityResponse.md) |  | [optional] 
**section_81_severity_string** | **str** |  | [optional] 
**section_81_status** | [**Section81StatusResponse**](Section81StatusResponse.md) |  | 
**section_81_status_string** | **str** |  | 
**section_81_type** | [**Section81TypeResponse**](Section81TypeResponse.md) |  | [optional] 
**section_81_type_string** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

